@@ -11,10 +11,7 @@ OC.L10N.register(
     "First name" : "Fornamn",
     "Last name" : "Etternamn",
     "Last modified" : "Siste endra",
-    "Password protection" : "Password protection",
     "Save" : "Lagre",
-    "Description" : "Skildring",
-    "Settings" : "nstillingar",
     "Cancel" : "Avbryt",
     "Invalid image" : "Ugyldig bilete",
     "Name" : "Namn",
