@@ -4,6 +4,8 @@ OC.L10N.register(
     "Import contacts" : "导入联系人",
     "Details" : "详情",
     "All contacts" : "全部联系人",
+    "_Imported 1 contact_::_Imported %n contacts_" : ["已导入 %n 个联系人"],
+    "_Imported 1 contact (skipped %d)_::_Imported %n contacts (skipped %d)_" : ["已导入 %n 个联系人（跳过 %d 个）"],
     "Contacts" : "联系人",
     "A contacts app for Nextcloud" : "适用于 Nextcloud 的联系人应用",
     "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud通讯录应用程序是Nextcloud的CardDAV服务器用户界面。您可以轻松使用您的Nextcloud同步各设备上的联系人，并在线上编辑。\n\n* 🚀 **与其他Nextcloud应用程序整合！** 目前有邮件和日历，还会有更多。\n* 🎉 **不会忘记生日！** 您可以将生日与其他重复的活动与您的Nextcloud日历同步。\n* 👥 **分享通讯录！** 您想与您的朋友或同事分享您的联系人吗？没问题！\n* 🙈 **我们不是在重复造轮子！** 基于出色且开源的SabreDAV库。",
@@ -13,11 +15,13 @@ OC.L10N.register(
     "There was an error fetching the member list" : "获取成员列表时发生一个错误",
     "Please select a team" : "请选择团队",
     "Loading team…" : "正在加载团队…",
+    "Loading contacts …" : "正在加载联系人 …",
     "There are no contacts yet" : "尚无联系人",
     "Create contact" : "创建联系人",
     "There are no contacts in this group" : "此群组中没有联系人",
     "Create contacts" : "新建联系人",
     "Add contacts" : "添加联系人",
+    "Loading …" : "正在加载 …",
     "Manage team" : "管理团队",
     "Leave team" : "离开团队",
     "Delete team" : "删除团队",
@@ -58,7 +62,6 @@ OC.L10N.register(
     "Unshare {addressbook}?" : "取消共享 {addressbook}？ ",
     "Deletion of address book was not successful." : "通讯录删除不成功",
     "Renaming of address book was not successful." : "通讯录重命名不成功",
-    "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
     "Download" : "下载",
     "Show" : "显示",
     "Unshare from me" : "我取消的共享",
@@ -90,6 +93,7 @@ OC.L10N.register(
     "An error happened during the config change" : "更改配置时发生一个错误",
     "Enforce password protection on files shared to this team" : "对与此团队共享的文件强制实施密码保护",
     "Use a unique password for all shares to this team" : "为此团队的全部共享使用唯一密码",
+    "Unique password …" : "唯一密码 …",
     "Save" : "保存",
     "Change unique password" : "修改独立密码",
     "Failed to save password. Please try again later." : "保存密码失败，请稍后重试。",
@@ -161,6 +165,7 @@ OC.L10N.register(
     "Please select at least one editable contact to delete" : "请至少选择一个可编辑的联系人进行删除",
     "Please select two editable contacts to merge" : "请选择两个可编辑的联系人进行合并",
     "Are you sure you want to proceed?" : "是否确定要继续？",
+    "Search contacts …" : "搜索联系人 …",
     "Unselect {number}" : "取消选择 {number}",
     "Add to {group}" : "添加到 {group}",
     "Add members to {group}" : "将成员添加到 {group}",
@@ -194,11 +199,13 @@ OC.L10N.register(
     "Unable to get the results" : "无法获得结果",
     "Some members could not be added" : "无法添加一些成员",
     "There was an issue adding members to the team" : "向团队添加成员时出现问题",
+    "Loading members list …" : "正在加载成员列表 …",
     "The list of members is only visible to members of this team" : "成员列表仅对此团队的成员可见",
     "You currently have no access to the member list" : "您目前无法访问成员列表",
     "Add to {team}" : "添加到 {team}",
     "Invite members to {team}" : "邀请成员加入 {team}",
     "Pending" : "待定",
+    "Select chart …" : "选择图表 …",
     "Chart" : "图表",
     "Select Date" : "选择日期",
     "Select type" : "选择类型",
@@ -327,13 +334,14 @@ OC.L10N.register(
     "Unable to create team {circleName}" : "无法创建团队 {circleName}",
     "Unable to delete team {circleId}" : "无法删除团队 {circleId}",
     "Unable to delete contact" : "无法删除联系人",
-    "Loading contacts …" : "正在加载联系人 ...",
+    "Loading contacts …" : "正在加载联系人…",
     "Loading …" : "正在加载…",
-    "Unique password …" : "独立密码 ...",
-    "Search contacts …" : "搜索联系人 ...",
+    "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
+    "Unique password …" : "唯一密码…",
+    "Search contacts …" : "搜索联系人…",
     "Invite members to team" : "邀请成员加入团队",
-    "Loading members list …" : "正在加载成员列表 ...",
+    "Loading members list …" : "正在加载成员列表…",
     "Add to {circle}" : "添加到 {circle}",
-    "Select chart …" : "选择图表 ..."
+    "Select chart …" : "选择图表…"
 },
 "nplurals=1; plural=0;");
